pub fn resolve(ctx: &mut CssContext<'_>) -> Option<CssState>Expand description
Acquire a CSS title key using whichever inputs the context provides.
Order of attempts:
- SCSI auth path (when
driveandauth_lbaare set). - Crack path (when
readerandextentsare set).
Returns None if neither path is configured or both fail.